==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/databaseimporter/SqlBatchImporterConfig.h <==
/****************************************************************************************
 * Copyright (c) 2010 Ralf Engels <ralf-engels@gmx.de>                                  *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AMAROK_SQLBATCH_IMPORTER_CONFIG_H
#define AMAROK_SQLBATCH_IMPORTER_CONFIG_H

#include <KVBox>

#include <QString>

class QLabel;
class QLineEdit;

class SqlBatchImporterConfig : public KVBox
{
    Q_OBJECT

    public:
        SqlBatchImporterConfig( QWidget *parent = 0 );
        virtual ~SqlBatchImporterConfig() { }

        QString inputFilePath() const;

    private:
        QLineEdit *m_inputFilePathInput;
};

#endif

==> amarok_3.0.1.orig.tar.xz: amarok-3.0.1/src/databaseimporter/SqlBatchImporterConfig.h <==
/****************************************************************************************
 * Copyright (c) 2010 Ralf Engels <ralf-engels@gmx.de>                                  *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AMAROK_SQLBATCH_IMPORTER_CONFIG_H
#define AMAROK_SQLBATCH_IMPORTER_CONFIG_H

#include "widgets/BoxWidget.h"

#include <QFrame>
#include <QString>

class QLineEdit;

class SqlBatchImporterConfig : public BoxWidget
{
    Q_OBJECT

    public:
        explicit SqlBatchImporterConfig( QWidget *parent = nullptr );
        ~SqlBatchImporterConfig() override { }

        QString inputFilePath() const;

    private:
        QLineEdit *m_inputFilePathInput;
};

#endif
